﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Threading;
using System.Management;

namespace TweakAPI.Info
{   
    /// <summary>
    /// Provides information about the installed baseboards.
    /// </summary>
    public struct Baseboard
    {
        private static ManagementObjectSearcher searcher1 = new ManagementObjectSearcher(@"root\CIMV2", "SELECT * FROM Win32_MotherboardDevice");
        private static ManagementObjectSearcher searcher2 = new ManagementObjectSearcher(@"root\CIMV2", "SELECT * FROM Win32_BaseBoard");

        /// <summary>
        /// Returns an <see cref="Baseboard"/>-Array containing information about all installed baseboards.
        /// </summary>
        /// <returns></returns>
        public static Baseboard[] EnumerateBoards()
        {
            List<Baseboard> boards = new List<Baseboard>();
            foreach (ManagementObject obj in searcher2.Get())
            {
                Baseboard board = new Baseboard();
                try { board.Name = obj["Name"].ToString(); } catch { }
                try { board.DeviceID = obj["DeviceID"].ToString(); } catch { }
                try { board.Depth = int.Parse(obj["Depth"].ToString()); } catch { }
                try { board.Height = int.Parse(obj["Height"].ToString()); } catch { }
                try { board.IsHostingBoard = bool.Parse(obj["HostingBoard"].ToString()); } catch { }
                try { board.IsHotSwappable = bool.Parse(obj["HotSwappable"].ToString()); } catch { }
                try { board.Manufacturer = obj["Manufacturer"].ToString(); } catch { }
                try { board.PartNumber = int.Parse(obj["PartNumber"].ToString()); } catch { }
                try { board.PoweredOn = bool.Parse(obj["PoweredOn"].ToString()); } catch { }
                try { board.Product = obj["Product"].ToString(); } catch { }
                try { board.IsRemovable = bool.Parse(obj["Removable"].ToString()); } catch { }
                try { board.IsReplaceable = bool.Parse(obj["IsReplaceable"].ToString()); } catch { }
                try { board.RequiresDaughterBoard = bool.Parse(obj["RequiresDaughterBoard"].ToString()); } catch { }
                try { board.SerialNumber = obj["SerialNumber"].ToString(); } catch { }
                try { board.SKU = obj["SKU"].ToString(); } catch { }
                try { board.SlotLayout = obj["SlotLayout"].ToString(); } catch { }
                try { board.Version = obj["Version"].ToString(); } catch { }
                try { board.Weight = int.Parse(obj["Weight"].ToString()); } catch { }
                try { board.Width = int.Parse(obj["Width"].ToString()); } catch { }
                boards.Add(board);
            }
            return boards.ToArray();
        }

        /// <summary>
        /// The name.
        /// </summary>
        public string Name { get; set; }
        /// <summary>
        /// The device ID.
        /// </summary>
        public string DeviceID { get; set; }
        /// <summary>
        /// The physical depth.
        /// </summary>
        public int Depth { get; set; }
        /// <summary>
        /// The physical height.
        /// </summary>
        public int Height { get; set; }
        /// <summary>
        /// Information, whether it is the hosting board.
        /// </summary>
        public bool IsHostingBoard { get; set; }
        /// <summary>
        /// Information, whether it is hot swappable.
        /// </summary>
        public bool IsHotSwappable { get; set; }
        /// <summary>
        /// The manufacturer  .
        /// </summary>
        public string Manufacturer { get; set; }
        /// <summary>
        /// The part number.
        /// </summary>
        public int PartNumber { get; set; }
        /// <summary>
        /// Information, whether it is powered on.
        /// </summary>
        public bool PoweredOn { get; set; }
        /// <summary>
        /// The caption of the product.
        /// </summary>
        public string Product { get; set; }
        /// <summary>
        /// Information, whether it is removable.
        /// </summary>
        public bool IsRemovable { get; set; }
        /// <summary>
        /// Information, whether it is replaceable.
        /// </summary>
        public bool IsReplaceable { get; set; }
        /// <summary>
        /// Information, whether it requires a daughter board.
        /// </summary>
        public bool RequiresDaughterBoard { get; set; }
        /// <summary>
        /// The serial number.
        /// </summary>
        public string SerialNumber { get; set; }
        /// <summary>
        /// The SKU.
        /// </summary>
        public string SKU { get; set; }
        /// <summary>
        /// The slot layout.
        /// </summary>
        public string SlotLayout { get; set; }
        /// <summary>
        /// The version.
        /// </summary>
        public string Version { get; set; }
        /// <summary>
        /// The physical weight.
        /// </summary>
        public int Weight { get; set; }
        /// <summary>
        /// The physical width.
        /// </summary>
        public int Width { get; set; }
    }
}
