﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;
using Microsoft.Win32;

namespace TweakAPI.Tweak
{
    /// <summary>
    /// Provides possibilities to customize general settings.
    /// </summary>
    public static class General
    {
        /// <summary>
        /// Enables/disables the Godmode.
        /// </summary>
        public static bool GodMode
        {
            get
            {
                return Directory.Exists(Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Desktop), 
                    "God-Modus.{ED7BA470-8E54-465E-825C-99712043E01C}"));
            }
            set
            {
                if (value)
                { Directory.CreateDirectory(Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Desktop), 
                    "God-Modus.{ED7BA470-8E54-465E-825C-99712043E01C}")); }
                else
                { Directory.Delete(Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.Desktop), 
                    "God-Modus.{ED7BA470-8E54-465E-825C-99712043E01C}")); }
            }
        }

        /// <summary>
        /// Enables/disables the confirmation when a file will be deleted.
        /// </summary>
        public static bool DeleteConfirmation
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("ConfirmFileDelete").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree) .CreateSubKey("Explorer", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { regKey.SetValue("ConfirmFileDelete", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("ConfirmFileDelete", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables automatic reboot to install Windows updates.
        /// </summary>
        public static bool AutoReboot
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\WindowsUpdate\\AU", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoAutoRebootWithLoggedOnUsers").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\WindowsUpdate\\AU", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("WindowsUpdate", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("AU", RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
           
                if (value)
                { regKey.SetValue("NoAutoRebootWithLoggedOnUsers", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoAutoRebootWithLoggedOnUsers", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Changes updates will be automatically installed on shutdown/restart/sleep.
        /// </summary>
        public static bool AUAsDefaultShutdown
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\WindowsUpdate\\AU", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoAUAsDefaultShutdownOption").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\WindowsUpdate\\AU", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("WindowsUpdate", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("AU", RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
           
                if (value)
                { regKey.SetValue("NoAUAsDefaultShutdownOption", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoAUAsDefaultShutdownOption", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables the Win+X shortcut.
        /// </summary>
        public static bool WinX
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoWinKeys").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("Explorer", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { regKey.SetValue("NoWinKeys", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoWinKeys", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables the Task-Manager.
        /// </summary>
        public static bool TaskManager
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\System", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("DisableTaskMgr").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\System", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("System", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
                
                if (value)
                { regKey.SetValue("DisableTaskMgr", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("DisableTaskMgr", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables the internet search for an unknown filetype. 
        /// </summary>
        public static bool WebSearchPrompt
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoInternetOpenWith").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\Explorer", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("NoInternetOpenWith", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoInternetOpenWith", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables an automatic restart after a system crash.
        /// </summary>
        public static bool CrashReboot
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\CrashControl", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("AutoReboot").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\CrashControl", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("AutoReboot", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("AutoReboot", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Changes the time which Windows provides all services and processes to close themselves.
        /// </summary>
        public static int WaitToKillServiceTimeout
        {
            get
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                return int.Parse(regKey.GetValue("WaitToKillServiceTimeout").ToString());
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                RegistryKey regKey2 = Registry.CurrentUser.OpenSubKey("Control Panel\\Desktop", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                regKey.SetValue("WaitToKillServiceTimeout", value, RegistryValueKind.String);
                regKey2.SetValue("WaitToKillAppTimeout", value, RegistryValueKind.String);
            }
        }

        /// <summary>
        /// Enables/disables error reporting.
        /// </summary>
        public static bool ErrorReporting
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\PCHealth\\ErrorReporting", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("DoReport").ToString()); }
                catch { return true; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\PCHealth\\ErrorReporting", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("PCHealth", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("ErrorReporting", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { 
                    regKey.SetValue("DoReport", 1, RegistryValueKind.DWord);
                    regKey.SetValue("ShowUI", 1, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeKernelFaults", 1, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeMicrosoftApps", 1, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeWindowsApps", 1, RegistryValueKind.DWord);
                }
                else
                {
                    regKey.SetValue("DoReport", 0, RegistryValueKind.DWord);
                    regKey.SetValue("ShowUI", 0, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeKernelFaults", 0, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeMicrosoftApps", 0, RegistryValueKind.DWord);
                    regKey.SetValue("IncludeWindowsApps", 0, RegistryValueKind.DWord);
                }
            }
        }

        /// <summary>
        /// Enables/disables file and print sharing.
        /// </summary>
        public static bool FilePrintSharing
        {
            get
            {
                int ans1 = 0;
                int ans2 = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans1 = int.Parse(regKey.GetValue("NoFileSharing").ToString()); }
                catch { return true; }

                try { ans2 = int.Parse(regKey.GetValue("NoPrintSharing").ToString()); }
                catch { return true; }
                
                if (ans1 == 0 && ans2 == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { 
                    regKey.SetValue("NoFileSharing", 0, RegistryValueKind.DWord);
                    regKey.SetValue("NoPrintSharing", 0, RegistryValueKind.DWord);
                }
                else
                { 
                    regKey.SetValue("NoFileSharing", 1, RegistryValueKind.DWord);
                    regKey.SetValue("NoPrintSharing", 1, RegistryValueKind.DWord);
                }
            }
        }

        /// <summary>
        /// Enables/disables kernel paging.
        /// </summary>
        public static bool KernelPaging
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\Session Manager" + 
                    "\\Memory Management", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("DisablePagingExecutive").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\Session Manager" + 
                    "\\Memory Management", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("DisablePagingExecutive", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("DisablePagingExecutive", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Changes whether the page file is being cleaned at shutdown.
        /// </summary>
        public static bool ClearPageFile
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\Session Manager" + 
                    "\\Memory Management", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("ClearPageFileAtShutdown").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Control\\Session Manager" + 
                    "\\Memory Management", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("ClearPageFileAtShutdown", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("ClearPageFileAtShutdown", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables defragmentation of boot files.
        /// </summary>
        public static bool BootDefragmentation
        {
            get
            {
                string ans = "";
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Dfrg\\BootOptimizeFunction", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = regKey.GetValue("Enable").ToString(); }
                catch { return false; }
                if (ans == "Y")
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Dfrg\\BootOptimizeFunction", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("Enable", "Y", RegistryValueKind.String); }
                else
                { regKey.SetValue("Enable", "N", RegistryValueKind.String); }
            }
        }

        /// <summary>
        /// Enables/disables the bandwidth limit.
        /// </summary>
        public static bool BandwidthLimit
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\Psched", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NonBestEffortLimit").ToString()); }
                catch { return true; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows\\Psched", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Policies\\Microsoft\\Windows", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("Psched", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
                    
                if (value)
                { regKey.SetValue("NonBestEffortLimit", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NonBestEffortLimit", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Shows/hides details about system status during logging in.  
        /// </summary>
        public static bool VerboseLogging
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\System", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("VerboseStatus").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion" + 
                    "\\Policies\\System", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("VerboseStatus", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("VerboseStatus", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Returns the registered owner on this computer or changes him.
        /// </summary>
        public static string RegisteredOwner
        {
            get
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                return regKey.GetValue("RegisteredOwner").ToString();
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                regKey.SetValue("RegisteredOwner", value, RegistryValueKind.String);
            }
        }

        /// <summary>
        /// Enables/disables running of multiple Explorer instances in seperate processes.
        /// </summary>
        public static bool SeperateExplorerProcess
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer" + 
                    "\\Advanced", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("SeperateProcess").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer" + 
                    "\\Advanced", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("SeperateProcess", 1, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("SeperateProcess", 0, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Changes whether Windows crashes if you hold ctrl und press scroll twice.
        /// </summary>
        public static bool CrashOnCtrlScroll
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Services\\kbdhid\\Parameters", 
                    RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return false; }

                try { ans = int.Parse(regKey.GetValue("CrashOnCtrlScroll").ToString()); }
                catch { return false; }
                if (ans == 1)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Services\\kbdhid\\Parameters", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);
                RegistryKey regKey2 = Registry.LocalMachine.OpenSubKey("SYSTEM\\CurrentControlSet\\Services\\i8042prt\\Parameters", 
                    RegistryKeyPermissionCheck.ReadWriteSubTree);

                if (value)
                {
                    regKey.SetValue("CrashOnCtrlScroll", 1, RegistryValueKind.DWord);
                    regKey2.SetValue("CrashOnCtrlScroll", 1, RegistryValueKind.DWord);
                }
                else
                {
                    regKey.SetValue("CrashOnCtrlScroll", 0, RegistryValueKind.DWord);
                    regKey2.SetValue("CrashOnCtrlScroll", 0, RegistryValueKind.DWord);
                }
            }
        }

        /// <summary>
        /// Enables/disables the Mobility Center.
        /// </summary>
        public static bool MobilityCenter
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\MobilityCenter", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoMobilityCenter").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\MobilityCenter", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("MobilityCenter", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
                  
                if (value)
                { regKey.SetValue("NoMobilityCenter", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoMobilityCenter", 1, RegistryValueKind.DWord); }
            }
        }
    }
}
