﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.Win32;

namespace TweakAPI.Tweak
{
    /// <summary>
    /// Provides possibilities to customize the security screen (Ctrl+Alt+Del).
    /// </summary>
    public static class SecurityScreen
    {
        /// <summary>
        /// Enables/disables fast user switching.
        /// </summary>
        public static bool FastUserSwitching
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("HideFastUserSwitching").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.LocalMachine.OpenSubKey("SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (value)
                { regKey.SetValue("HideFastUserSwitching", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("HideFastUserSwitching", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables the shut down of the computer from the security screen.
        /// </summary>
        public static bool CanShutdown
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\Explorer", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoClose").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\Explorer", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("Explorer", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }
                    
                if (value)
                { regKey.SetValue("NoClose", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoClose", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables logging off on the security screen.
        /// </summary>
        public static bool CanLogoff
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\Explorer", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("NoLogoff").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\Explorer", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("Explorer", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { regKey.SetValue("NoLogoff", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("NoLogoff", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables locking the computer.
        /// </summary>
        public static bool CanLockWorkstation
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("DisableLockWorkstation").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("System", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { regKey.SetValue("DisableLockWorkstation", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("DisableLockWorkstation", 1, RegistryValueKind.DWord); }
            }
        }

        /// <summary>
        /// Enables/disables accessing the task manager from the security screen.
        /// </summary>
        public static bool TaskManager
        {
            get
            {
                int ans = 0;
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadSubTree);
                if (regKey == null)
                { return true; }

                try { ans = int.Parse(regKey.GetValue("DisableLockWorkstation").ToString()); }
                catch { return true; }
                if (ans == 0)
                { return true; }
                else
                { return false; }
            }
            set
            {
                RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies" + 
                    "\\System", RegistryKeyPermissionCheck.ReadWriteSubTree);
                if (regKey == null)
                {
                    regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Policies", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree).CreateSubKey("System", 
                        RegistryKeyPermissionCheck.ReadWriteSubTree);
                }

                if (value)
                { regKey.SetValue("DisableTaskMgr", 0, RegistryValueKind.DWord); }
                else
                { regKey.SetValue("DisableTaskMgr", 1, RegistryValueKind.DWord); }
            }
        }
    }
}
